use std::{thread, time::Duration};

use gilrs::{
	ff::{BaseEffect, BaseEffectType, EffectBuilder, Replay, Ticks},
	Gamepad, Gilrs,
};

fn main() {
	let mut gilrs = Gilrs::new().unwrap();

	let mut counter = 0;

	// Iterate over all connected gamepads
	for (_, gamepad) in Gilrs::new().unwrap().gamepads() {
		println!("{} is {:?}", gamepad.name(), gamepad.power_info());
		println!("Has Force Feedback Enabled ? {}", gamepad.is_ff_supported());
		test_ff(&mut gilrs, gamepad);
		counter += 1;
	}

	if counter <= 0 {
		println!("No gamepads found!");
	}
}

fn test_ff(gilrs: &mut Gilrs, gamepad: Gamepad) {
	let duration: u32 = 1000;
	let ff_play_ticks = Ticks::from_ms(duration);
	let effect = EffectBuilder::new()
		.add_effect(BaseEffect {
			kind: BaseEffectType::Strong { magnitude: 40_000 },
			scheduling: Replay {
				play_for: ff_play_ticks,
				with_delay: ff_play_ticks * 2,
				..Default::default()
			},
			envelope: Default::default(),
		})
		.add_effect(BaseEffect {
			kind: BaseEffectType::Weak { magnitude: 40_000 },
			scheduling: Replay {
				after: ff_play_ticks,
				play_for: ff_play_ticks,
				..Default::default()
			},
			envelope: Default::default(),
		})
		.add_gamepad(&gamepad)
		.finish(gilrs)
		.unwrap();

	effect.play().unwrap();

	thread::sleep(Duration::from_millis((duration * 2) as u64));
}
